#
# view-xos-cert.sed: Sed commands to assist in pretty-printing the output
# of the OpenSSL 'x509' command
#
# Author: Ian Johnson, STFC Rutherford Appleton Laboratory. 23/10/08.
#

#
# The VO Attributes are stored in certificate extension fields.
# The numerical OID can be converted to the name of the attribute
# by the following sequence of substituion commands


#
# The first attribute, GlobalPrimaryVOName,  is preceded by a column heading
# showing where the VO Attributes start. Indent of first attribute name is 12 spaces.
#

s/1.34.5.0.14.1/\n\n        XtreemOS VO Attributes:\n\n            GlobalPrimaryVOName/
s/1.34.5.0.14.2/GlobalSecondaryVONames/
s/1.34.5.0.14.3/GlobalUserID/
s/1.34.5.0.14.4/GlobalPrimaryGroupName/
s/1.34.5.0.14.5/GlobalSecondaryGroupNames/
s/1.34.5.0.14.6/Role/
s/1.34.5.0.14.7/Group/
s/1.34.5.0.14.8/Subgroup/

#
# OpenSSL doesn't recognise the OIDs used for the XtreemOS attributes and
# doesn't decode the ASN.1 TLV format. Hence, the contents of the Type and Length
# fields in this encoding are often printed before the value of the extension
# field as mulitple dots '.' followed by a dollar '$'. 
# 
# The next command removes these extraneous characters from the output.
#
#
# Match the whitespace before the value of an extension field, any number of '.'s followed
# by an optional '$', and print just the whitespace matched by the first sub-expression.
#

s/\([ ]*\)\.\.*\$*/\1/

